proxy — Health Dashboard

# proxy — Good

Analyzed 2026-03-23 by code2llm · Primary language: python · Python: 110, JavaScript: 30, Shell: 7

1,441
Functions
118
Classes
131
Files
42,561
Lines
3
Languages
3.9
Avg CC
99
Critical (CC≥10)
0
Duplicates
0
Cycles

## Language Distribution

## Largest Modules (lines)

## Most Complex Modules (functions)

## Evolution

## Top Modules (147)

Module | Path | Lines | Funcs | Classes | CC max
--- | --- | --- | --- | --- | ---
tools.jsx | src/proxym/dashboard/components | 1,271 | 88 | 0 | 62
tasks.jsx | src/proxym/dashboard/components | 881 | 67 | 0 | 51
tickets.jsx | src/proxym/dashboard/components | 807 | 51 | 0 | 90
_tools_api.py | src/proxym/dashboard | 807 | 30 | 4 | 15
coverage_html_cb_dd2e7eb5.js | htmlcov | 735 | 65 | 0 | 21
adapters.py | src/proxym/tools | 616 | 14 | 6 | 24
validate_system.sh | scripts | 531 | 11 | 0 | 0
setup.jsx | src/proxym/dashboard/components | 519 | 27 | 0 | 16
projects.jsx | src/proxym/dashboard/components | 467 | 22 | 0 | 21
__init__.py | src/proxym/tools | 432 | 13 | 5 | 7
tickets.py | src/proxym/dashboard | 412 | 23 | 10 | 17
users.jsx | src/proxym/dashboard/components | 411 | 18 | 0 | 21
__init__.py | src/proxym/accounts | 398 | 20 | 8 | 15
frontend.py | src/proxym/api | 373 | 32 | 0 | 6
_tickets_api.py | src/proxym/dashboard | 363 | 16 | 6 | 9
__init__.py | src/proxym/router | 357 | 14 | 1 | 9
repair_agent.py | src/proxym/observability | 341 | 9 | 1 | 14
__init__.py | src/proxym/cache | 333 | 10 | 3 | 9
entrypoint.sh | services/vscode | 333 | 1 | 0 | 0
__init__.py | src/proxym/providers | 331 | 4 | 3 | 8

## Alerts (20)

Severity | Target | Type | Value | Limit
--- | --- | --- | --- | ---
critical | TicketDetailPanel | cc_exceeded | 90 | 15
critical | JobDetailsPanel | cc_exceeded | 62 | 15
critical | ToolHealthPanel | cc_exceeded | 58 | 15
critical | TicketDispatchTable | cc_exceeded | 52 | 15
critical | TasksPanel | cc_exceeded | 51 | 15
critical | ToolsPanel | cc_exceeded | 49 | 15
critical | TicketHistoryItem | cc_exceeded | 42 | 15
critical | LogPanel | cc_exceeded | 34 | 15
critical | useDashboardData | high_fan_out | 33 | 10
critical | VMsPanel | cc_exceeded | 32 | 15
critical | HumanTaskPanel | cc_exceeded | 31 | 15
critical | VoiceChat | high_fan_out | 31 | 10
critical | DiagRooConfig | cc_exceeded | 29 | 15
critical | TicketsPanel | cc_exceeded | 28 | 15
critical | run_all_tests | high_fan_out | 28 | 10

## Hotspots (10)

Function | Fan-out | Note
--- | --- | ---
useDashboardData | 33 | Orchestrates 33 calls
VoiceChat | 31 | Orchestrates 31 calls
run_all_tests | 28 | Run all diagnostic tests and return comprehensive status.
create_ticket | 27 | Create a new ticket. Accepts 'task' (new) or 'title' (legacy).
chat_completions | 27 | OpenAI-compatible chat completions with intelligent routing. Extra headers: X
TicketsPanel | 27 | Orchestrates 27 calls
TicketDispatchTable | 27 | 27-way dispatch
_llm_fallback_execute | 24 | Execute a task via LLM API when the tool binary is not available. Calls litellm
HumanTaskPanel | 24 | Orchestrates 24 calls
ToolHealthPanel | 24 | Orchestrates 24 calls

## Refactoring Priorities (15)

# | Action | Impact | Effort
--- | --- | --- | ---
1 | Split DiagnosticsPanel (CC=26 → target CC<10) | high | low
2 | Split LogPanel (CC=34 → target CC<10) | high | low
3 | Split VMsPanel (CC=32 → target CC<10) | high | low
4 | Split TaskJobBadge (CC=25 → target CC<10) | high | low
5 | Split HumanTaskPanel (CC=31 → target CC<10) | high | low
6 | Split TasksPanel (CC=51 → target CC<10) | high | low
7 | Split TicketHistoryItem (CC=42 → target CC<10) | high | low
8 | Split TicketDetailPanel (CC=90 → target CC<10) | high | low
9 | Split TicketsPanel (CC=28 → target CC<10) | high | low
10 | Split DiagRooConfig (CC=29 → target CC<10) | high | low
11 | Split JobDetailsPanel (CC=62 → target CC<10) | high | low
12 | Split TicketDispatchTable (CC=52 → target CC<10) | high | low
13 | Split ToolHealthPanel (CC=58 → target CC<10) | high | low
14 | Split ToolsPanel (CC=49 → target CC<10) | high | low
15 | Split god module src/proxym/dashboard/components/tickets.jsx (807L, 0 classes) | high | high